@@ -13,9 +13,9 @@ import uuid
 from typing import (
     Any, Dict, Optional, Callable)
 from vivarium.core.types import (
-    Topology, CompositeDict, HierarchyPath)
+    Topology, HierarchyPath)
 
-from vivarium.core.process import Process, Composer
+from vivarium.core.process import Process, Composer, Composite
 from vivarium.core.experiment import Experiment
 from vivarium.library.dict_utils import (
     deep_merge,
@@ -53,7 +53,7 @@ def add_processes_to_hierarchy(
         composer_type: Callable,
         composer_config: Optional[Dict[str, Any]] = None,
         composer_topology: Optional[Dict[str, Any]] = None
-) -> CompositeDict:
+) -> Composite:
     """Use a composer to add processes and topology"""
     composer_config = composer_config or {}
     composer_topology = composer_topology or {}
@@ -81,14 +81,14 @@ def add_processes_to_hierarchy(
     deep_merge(topology, new_topology)
     deep_merge_check(processes, new_processes)
 
-    return {
+    return Composite({
         'processes': processes,
-        'topology': topology}
+        'topology': topology})
 
 
 def initialize_hierarchy(
         hierarchy: Dict[str, Any]
-) -> CompositeDict:
+) -> Composite:
     """Make a hierarchy with initialized processes"""
     processes: Dict[str, Process] = {}
     topology: Topology = {}
@@ -117,9 +117,9 @@ def initialize_hierarchy(
             deep_merge_check(processes, {key: composite['processes']})
             deep_merge(topology, {key: composite['topology']})
 
-    return {
+    return Composite({
         'processes': processes,
-        'topology': topology}
+        'topology': topology})
 
 
 # list of keys expected in experiment settings
@@ -256,9 +256,9 @@ def process_in_experiment(
             port: override_topology.get(port, (port,))
             for port in process.ports_schema().keys()}}
 
-    composite = {
+    composite = Composite({
         'processes': processes,
-        'topology': topology}
+        'topology': topology})
 
     return composite_in_experiment(
         composite=composite,
@@ -268,7 +268,7 @@ def process_in_experiment(
 
 
 def composite_in_experiment(
-        composite: CompositeDict,
+        composite: Composite,
         settings: Dict[str, Any] = None,
         initial_state: Dict[str, Any] = None,
 ) -> Experiment:
@@ -353,7 +353,7 @@ def simulate_process(
 
 
 def simulate_composite(
-        composite: CompositeDict,
+        composite: Composite,
         settings: Optional[Dict[str, Any]] = None
 ) -> Dict:
     """Put a :term:`Composite` in an :term:`Experiment` and simulate it"""
