@@ -17,12 +17,14 @@ import numpy as np
 from pint.errors import UndefinedUnitError
 
 from vivarium.library.datum import Datum
-from vivarium.library.topology import inverse_topology
+from vivarium.library.topology import (
+    inverse_topology, convert_path_to_tuple, convert_topology_path)
 from vivarium.library.units import Quantity, Unit
 from vivarium.core.registry import serializer_registry
 from vivarium.library.dict_utils import deep_merge
 from vivarium.core.types import (
-    HierarchyPath, Topology, Schema, State, Update)
+    HierarchyPath, TuplePath, Topology,
+    Schema, State, Update, Processes)
 
 DEFAULT_TIME_STEP = 1.0
 
@@ -216,7 +218,7 @@ def _get_composite_state(
         processes: Dict[str, 'Process'],
         topology: Any,
         state_type: Optional[str] = 'initial',
-        path: Optional[HierarchyPath] = None,
+        path: Optional[TuplePath] = None,
         initial_state: Optional[State] = None,
         config: Optional[dict] = None,
 ) -> Optional[State]:
@@ -316,6 +318,7 @@ class Composite(Datum):
         processes = processes or {}
         topology = topology or {}
         path = path or tuple()
+        path = convert_path_to_tuple(path)
         schema_override = schema_override or {}
 
         # get the processes and topology to merge
@@ -383,7 +386,7 @@ class Composer(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def generate_processes(
             self,
-            config: Optional[dict]) -> Dict[str, Any]:
+            config: Optional[dict]) -> Processes:
         """Generate processes dictionary.
 
         Every subclass must override this method.
@@ -420,7 +423,7 @@ class Composer(metaclass=abc.ABCMeta):
     def generate(
             self,
             config: Optional[dict] = None,
-            path: HierarchyPath = ()) -> Composite:
+            path: HierarchyPath = '') -> Composite:
         """Generate processes and topology dictionaries.
 
         Args:
@@ -441,9 +444,11 @@ class Composer(metaclass=abc.ABCMeta):
         else:
             default = copy.deepcopy(self.config)
             config = deep_merge(default, config)
+        path = convert_path_to_tuple(path)
 
         processes = self.generate_processes(config)
         topology = self.generate_topology(config)
+        topology = convert_topology_path(topology)
         _override_schemas(self.schema_override, processes)
 
         return Composite({
@@ -557,6 +562,7 @@ class Process(Composer, metaclass=abc.ABCMeta):
         self.parameters = self.config
         self.parallel = self.config.pop('_parallel', False)
         self.parameters.setdefault('time_step', DEFAULT_TIME_STEP)
+        self.schema = self.get_schema()
 
     def initial_state(self, config: Optional[dict] = None) -> State:
         """Get initial state in embedded path dictionary.
