@@ -9,12 +9,17 @@ from typing import Tuple, Dict, Any, Union
 
 #: Relative path between nodes in the :term:`hierarchy`. Like Unix file
 #: paths, ".." refers to the parent directory.
-HierarchyPath = Tuple[str, ...]
+TuplePath = Tuple[str, ...]
+HierarchyPath = Union[str, TuplePath]
 
 #: Mapping from :term:`ports` to paths that specify which node in the
 #: :term:`hierarchy` should be wired to each port.
 Topology = Dict[str, Union[HierarchyPath, dict]]
 
+#: Mapping from processes names to Processes, which can be embedded in
+#: a hierarchy.
+Processes = Dict[str, Any]
+
 #: A dictionary that specifies a :term:`schema`.
 Schema = Dict[str, Any]
 
