@@ -10,14 +10,13 @@ from typing import Any, Dict
 from vivarium.core.experiment import pp
 from vivarium.core.process import (
     Deriver,
-    Factory,
+    Composer,
 )
 from vivarium.core.composition import (
-    simulate_compartment_in_experiment,
+    simulate_composer,
     PROCESS_OUT_DIR,
 )
-from vivarium.processes.exchange_a import ExchangeA
-
+from vivarium.composites.toys import ExchangeA
 
 NAME = 'remove'
 
@@ -51,7 +50,7 @@ class Remove(Deriver):
 
 
 # test
-class ToyLivingCompartment(Factory):
+class ToyLivingCompartment(Composer):
     defaults = {
         'exchange': {'uptake_rate': 0.1},
         'death': {}
@@ -104,7 +103,7 @@ def test_remove():
         'timeline': {
             'timeline': timeline},
         'initial_state': initial_state}
-    output = simulate_compartment_in_experiment(
+    output = simulate_composer(
         compartment,
         settings)
 
@@ -116,8 +115,7 @@ def test_remove():
 
 def run_remove():
     out_dir = os.path.join(PROCESS_OUT_DIR, NAME)
-    if not os.path.exists(out_dir):
-        os.makedirs(out_dir)
+    os.makedirs(out_dir, exist_ok=True)
     output = test_remove()
     pp(output)
 
